@@ -2,6 +2,12 @@
 Various exception classes raised by ponepassword API
 TODO: Move other exception classes here
 """
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from .op_items._item_list import OPItemList
 
 
 class OPBaseException(Exception):
@@ -34,7 +40,7 @@ class OPCmdFailedException(OPBaseException):
         self.returncode = returncode
 
     @classmethod
-    def from_opexception(cls, ope):
+    def from_opexception(cls, ope: OPCmdFailedException):
         return cls(ope.err_output, ope.returncode)
 
 
@@ -80,6 +86,34 @@ class OPItemDeleteException(OPCmdFailedException):
         super().__init__(stderr_out, returncode)
 
 
+class OPItemDeleteMultipleException(OPItemDeleteException):
+    """
+    Exception class for OP.item_delete_multiple() failures
+
+    Contains list of deleted items, if any, before the failure occured
+    """
+    MSG = "1Password 'item delete' for multiple objects failed."
+
+    def __init__(self, deleted_items: OPItemList, stderr_out, returncode):
+        """
+        Parameters
+        ----------
+        deleted_items : OPItemList
+            List of items that were deleted before the failure occured
+        stderr_out : str
+            Error output from the 'op' command
+        returncode : int
+            Exit status of the 'op' op command
+        """
+        self.deleted_items = deleted_items
+        super().__init__(stderr_out, returncode)
+
+    @classmethod
+    # type: ignore[override]
+    def from_opexception(cls, ope: OPCmdFailedException, deleted_items: OPItemList):
+        return cls(deleted_items, ope.err_output, ope.returncode)
+
+
 class OPDocumentGetException(OPCmdFailedException):
     MSG = "1Password 'document get' failed."
 
